@@ -336,7 +336,7 @@ class DataPlotterCallback(Callback):
         self.previous_batch = 0
         for sample_index in range(self.data_set_sample_count):
             if self.shuffle:
-                sample_index = random.randint(0, len(self.data_set))
+                sample_index = random.randint(0, len(self.data_set) - 1)
             input_real, output_real = self.data_set.__getitem__(sample_index)
             self.inputs_outputs_real.append((input_real, output_real))
     
